import org.jetbrains.kotlin.gradle.tasks.KotlinCompile
import com.github.jengelman.gradle.plugins.shadow.tasks.ShadowJar

plugins {
    id("com.squareup.sqldelight")
    id("org.sonarqube")
    id("com.github.johnrengelman.shadow")
    kotlin("jvm") version "1.7.10"
}

group = "fr.louveauAmine"
version = "1.0-SNAPSHOT"

repositories {
    mavenCentral()
}

dependencies {
    testImplementation(kotlin("test"))
    implementation("io.javalin:javalin:4.6.4")
    implementation("org.slf4j:slf4j-simple:2.0.1")
    implementation("com.squareup.sqldelight:sqlite-driver:1.5.3")
    implementation("com.fasterxml.jackson.core:jackson-databind:2.13.4")
    implementation("com.fasterxml.jackson.module:jackson-module-kotlin:2.13.4")
}

tasks.test {
    useJUnitPlatform()
}

tasks.withType<KotlinCompile> {
    kotlinOptions.jvmTarget = "1.8"
}

tasks.withType<Jar> {
    manifest {
        attributes["Main-Class"] = "ServerKt"
    }
}

sqldelight {
    database("CVApiDB") {
        packageName = "fr.louveauAmine.cvApi.dao"
        sourceFolders = listOf("sqldelight")
    }
}

tasks.withType<ShadowJar> {
    mergeServiceFiles()
    manifest {
        attributes(mapOf("Main-Class" to "ServerKt"))
    }
}

tasks {
    build {
        dependsOn(shadowJar)
    }
}